@@ -189,7 +189,8 @@ def get_stats_from_client(client):
     io_data = None
     http_response = None
 
-    if client_ping_response(client) == 0:
+    ping_resp = client_ping_response(client)
+    if ping_resp == 0:
         try:
             LOGGER.info('Requesting stats from %s', client.host_name)
             http_conn = httplib.HTTPConnection(host=client.ip_address, port=client.port, timeout=3)
@@ -213,6 +214,7 @@ def get_stats_from_client(client):
             LOGGER.error("Client %s responded with %s", client.host_name, http_response.status)
     else:
         client.is_unreachable = True
+        LOGGER.error('Client %s responded to ping with %s', client.host_name, ping_resp)
         client.save()
 
 
